;/*************************************************************************
** STR V3.1                                                              **
** str.c                                                                 **
** Copyright (C) 2012  Jean-Marc Drezet                                  **
**                                                                       **
**  This library is free software; you can redistribute it and/or        **
**  modify it under the terms of the GNU Library General Public          **
**  License as published by the Free Software Foundation; either         **
**  version 2 of the License, or (at your option) any later version.     **
**                                                                       **
**  This library is distributed in the hope that it will be useful,      **
**  but WITHOUT ANY WARRANTY; without even the implied warranty of       **
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU    **
**  Library General Public License for more details.                     **
**                                                                       **
**  You should have received a copy of the GNU Library General Public    **
**  License along with this library; if not, write to the Free           **
**  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.   **
**                                                                       **
** Please mail any bug reports/fixes/enhancements to me at:              **
**      drezet@math.jussieu.fr                                           **
** or                                                                    **
**      Jean-Marc Drezet                                                 **
**      Institut de Mathematiques de Jussieu                             **
**      UMR 7586 du CNRS                                                 **
**      4, place Jussieu                                                 **
**      75252 Paris                                                      **
**      France                                                           **
**                                                                       **
**************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "interp.h"
#include "liste.h"



/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
int
ch_str(char *str, char *p, int n)
{
    int             i,
                    j,
                    k,
                    l,
                    lp;

    l = strlen(str);
    lp = strlen(p);
    k = -1;

    for (i = n; i < l - lp; i++) {
        k = 1;
        for (j = 0; j < lp; j++)
            if (str[j + i] != p[j])
                k = 0;
        if (k == 1)
            break;
    }

    if (k == 1)
        return i + lp;
    else
        return -1;
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
int
extr_str(char *str, char *deb, char *fin, char ***m, int Kd, int Kf)
{
    int             i,
                    ii,
                    iw,
                    j,
                    k,
                    i2,
                    l,
                    ld,
                    lf,
                    n,
                   *nn,
                   *nn2;
    char           *deb2,
                   *fin2;

    l = strlen(str);
    ld = strlen(deb);
    lf = strlen(fin);
    if (l == 0 || ld == 0 || lf == 0)
        return -1;

    if (Kd != 0) {
        deb2 = ch_copy(deb);

        for (i = 0; i < ld; i++) {
            j = (int) deb[i];
            if (j >= 65 && j <= 90)
                deb2[i] += 32;
            if (j >= 97 && j <= 122)
                deb2[i] -= 32;
        }
    }

    if (Kf != 0) {
        fin2 = ch_copy(fin);

        for (i = 0; i < lf; i++) {
            j = (int) fin[i];
            if (j >= 65 && j <= 90)
                fin2[i] += 32;
            if (j >= 97 && j <= 122)
                fin2[i] -= 32;
        }
    }

    i = -1;
    n = 0;
    nn = (int *) malloc((size_t) l * sizeof(int));
    nn2 = (int *) malloc((size_t) l * sizeof(int));
    for (j = 0; j < l; j++)
        nn2[j] = -1;

    while (i < l - ld) {
        k = 1;
        i++;
        ii = i - 1;

        if (Kd == 0) {
            for (j = 0; j < ld; j++) {
                ii++;
                if (str[ii] != deb[j]) {
                    k = 0;
                    break;
                }
            }
        }
        else {
            for (j = 0; j < ld; j++) {
                ii++;
                if (str[ii] != deb[j] && str[ii] != deb2[j]) {
                    k = 0;
                    break;
                }
            }
        }

        if (k == 1) {
            i = ii;
            nn[n] = i;
            n++;
        }
    }

    for (i = 0; i < n; i++) {
        j = nn[i];
        iw = l - lf;
        if (i < n - 1)
            iw = nn[i + 1] - lf;

        while(j <= iw) {
            j++;
            k = 1;
            ii = j - 1;

            if (Kf == 0) {
                for (i2 = 0; i2 < lf; i2++) {
                    ii++;
                    if (str[ii] != fin[i2]) {
                        k = 0;
                        break;
                    }
                }
            }
            else {
                 for (i2 = 0; i2 < lf; i2++) {
                    ii++;
                    if (str[ii] != fin[i2] && str[ii] != fin2[i2]) {
                        k = 0;
                        break;
                    }
                }
            }

            if (k == 1) {
                j = ii;
                nn2[i] = j;
                break;
            }
        }
    }

    j = -1;

    for (i = 0; i < n; i++) {
        if (nn2[i] >= 0) {
            j++;
            nn[j] = nn[i];
            nn2[j] = nn2[i];
        }
    }

    n = j + 1;
    if (n > 0)
        m[0] = (char **) malloc((size_t) (n + 1) * sizeof(char *));
    else
        m[0] = NULL;

    for (i = 0; i < n; i++) {
        k = nn2[i] - lf - nn[i];
        m[0][i] = (char *) malloc((size_t) (k + 10) * sizeof(char));
        for (j = 0; j < k; j++)
            m[0][i][j] = str[nn[i] + j + 1];
        m[0][i][k] = 0;
    }

    if (Kd != 0)
        free(deb2);
    if (Kf != 0)
        free(fin2);
    free(nn);
    free(nn2);
    return n;
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------
    Function returning 1 if the string k0 is before (or equal to) the string
    k1, and 0 otherwise
--------------------------------------------------------------------*/
int
est_avantb(char *k0, char *k1)
{
    int             i,
                    i0,
                    i1;

    i = 0;
    i0 = strlen(k0);
    i1 = strlen(k1);

    while (i < i0) {
        if (i >= i1)
            return 0;
        if (k0[i] < k1[i])
            return 1;
        if (k0[i] > k1[i])
            return 0;
        i++;
    }

    return 1;
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
int
lect_fic_art(char *fic_name, math_rec *D)
{
    char            ch1,
                   *hk,
                  **mm,
                   *m2,
                   *w;
    int             i,
                    ik,
                    i1,
                    ind,
                    j,
                    lin,
                    line_s,
                    len,
                    n,
                    n2;
    FILE           *S;

    S = fopen(fic_name, "r");
    if (S == NULL)
        return 1;
    j = 0;
    file_param(S, &lin, &line_s, &len);
    hk = (char *) malloc((size_t) (len + 100) * sizeof(char));
    memset(hk, 0, len + 100);
    while(fread(&ch1, 1, 1, S) == 1) {
        hk[j++] = ch1;
    }
    fclose(S);

/*--------------------------------
    Recherche des noms d'auteurs
--------------------------------*/
    n = extr_str(hk, "/1\">", "</a>", &mm, 1, 1);
    if (n == 0) {
        free(hk);
        return 2;
    }
    D->nb_aut = n;
    D->name_aut = (char **) malloc((size_t) (n + 1) * sizeof(char*));
    D->name_aut2 = (char **) malloc((size_t) (n + 1) * sizeof(char*));

    for (ik = 0; ik < n; ik++) {
        clean_fic(mm[ik]);
        D->name_aut[ik] = ch_copy(mm[ik]);
        extr_nam(D->name_aut[ik], &D->name_aut2[ik]);
        free(mm[ik]);
    }

    for (ik = 0; ik < n; ik++) {
        for (i = ik + 1; i < n; i++) {
            if (est_avantb(D->name_aut2[i], D->name_aut2[ik]) == 1) {
                echange_nom_b(&D->name_aut2[i], &D->name_aut2[ik]);
                echange_nom_b(&D->name_aut[i], &D->name_aut[ik]);
            }
        }
    }

    free(mm);
/*------------------------------*/

/*--------------------------------
    Recherche du titre
--------------------------------*/
    n2 = extr_str(hk, "<title>", "</title>", &mm, 1, 1);
    if (n2 == 0) {

        for (ik = 0; ik < n; ik++) {
            free(D->name_aut[ik]);
            free(D->name_aut2[ik]);
        }

        free(D->name_aut);
        free(D->name_aut2);
        D->nb_aut = 0;
        free(hk);
        return 3;
    }
    if (mm[0][0] == '[') {
        j = strlen(mm[0]);
        D->titre = (char *) malloc((size_t) (j + 1) * sizeof(char));
        memset(D->titre, 0, j + 1);
        ind = 0;
        i1 = 0;

        for (ik = 0; ik < j; ik++) {
            if (ind == 1) {
                D->titre[i1] = mm[0][ik];
                i1++;
            }
            else {
                if (mm[0][ik] == ']')
                    ind = 1;
            }
        }
    }
    else {
        for (ik = 0; ik < n2; ik++)
            free(mm[ik]);
        free(mm);
        n2 = extr_str(hk, "<H2>", "</H2>", &mm, 1, 1);
        if (n2 == 0) {
            for (ik = 0; ik < n; ik++) {
                free(D->name_aut[ik]);
                free(D->name_aut2[ik]);
            }

            free(D->name_aut);
            free(D->name_aut2);
            D->nb_aut = 0;
            free(hk);
            return 4;
        }
        D->titre = ch_copy(mm[0]);
    }

    for (ik = 0; ik < n2; ik++)
        free(mm[ik]);
    free(mm);
/*------------------------------*/

/*--------------------------------
    Recherche du rsum
--------------------------------*/
    n2 = extr_str(hk, "<BLOCKQUOTE", "</BLOCKQUOTE>", &mm, 1, 1);
    if (n2 == 0) {
        for (ik = 0; ik < n; ik++) {
            free(D->name_aut[ik]);
            free(D->name_aut2[ik]);
        }

        free(D->name_aut);
        free(D->name_aut2);
        free(D->titre);
        D->nb_aut = 0;
        free(hk);
        return 5;
    }
    m2 = (char *) malloc((size_t) (strlen(mm[0]) + 1) * sizeof(char));
    clean_resume(mm[0], &m2);
    D->resume = ch_copy(m2);
/*    if (m2[0] == '>')
        D->resume = ch_copy(mm[0] + 1);
    else {
        D->resume = NULL;
        w = ch_copy(m2);
        j = strlen(w);

        for (ik = 0; ik < j - 1; ik++) {
            if (w[ik] == 'n' && w[ik + 1] == '>')
                break;
        }

        if (ik == j - 2) {
            for (i1 = 0; i1 < n; i1++) {
                free(D->name_aut[i1]);
                free(D->name_aut2[i1]);
            }

            free(D->name_aut);
            free(D->name_aut2);
            free(D->titre);
            D->nb_aut = 0;
            free(w);
            free(hk);
            return 1;
        }
        D->resume = ch_copy(w + ik + 2);
        free(w);
    }*/
    for (ik = 0; ik < n2; ik++)
        free(mm[ik]);
    free(mm);
    free(m2);
    free(hk);
    return 0;
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
int
add_DB_STR(FILE *S, math_rec *D)
{
    int             i,
                    l;

    fprintf(S, "%s\n", D->ref);
    fprintf(S, "%d\n", D->nb_aut);

    for (i = 0; i < D->nb_aut; i++) {
        fprintf(S, "%s\n", D->name_aut[i]);
        fprintf(S, "%s\n", D->name_aut2[i]);
    }

    l = strlen(D->titre);
    for (i = 0; i < l; i++)
        if (D->titre[i] == '\n')
            D->titre[i] = ' ';
    fprintf(S, "%s\n", D->titre);
    l = strlen(D->resume);
    for (i = 0; i < l; i++)
        if (D->resume[i] == '\n')
            D->resume[i] = ' ';
    fprintf(S, "%s\n", D->resume);

    return 0;
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
int
lec_DB_STR(FILE *S, math_rec *D)
{
    int             i,
                    j;
    char            ch1;

    D->fic = NULL;
    D->ref = (char *) malloc(200 * sizeof(char));
    memset(D->ref, 0, 200);
    j= 0;
    while(fread(&ch1, 1, 1, S) == 1 && ch1 != '\n') {
        if (j < 200)
            D->ref[j++] = ch1;
    }
    fscanf(S, "%d\n", &D->nb_aut);
    D->name_aut = (char **) malloc(D->nb_aut * sizeof(char *));
    D->name_aut2 = (char **) malloc(D->nb_aut * sizeof(char *));

    for (i = 0; i < D->nb_aut; i++) {
        D->name_aut[i] = (char *) malloc(100 * sizeof(char));
        memset(D->name_aut[i], 0, 100);
        j= 0;
        while(fread(&ch1, 1, 1, S) == 1 && ch1 != '\n') {
            if (j < 100)
                D->name_aut[i][j++] = ch1;
        }
        D->name_aut2[i] = (char *) malloc(100 * sizeof(char));
        memset(D->name_aut2[i], 0, 100);
        j= 0;
        while(fread(&ch1, 1, 1, S) == 1 && ch1 != '\n') {
            if (j < 100)
                D->name_aut2[i][j++] = ch1;
        }
    }

    D->titre = (char *) malloc(400 * sizeof(char));
    memset(D->titre, 0, 400);
    j= 0;
    while(fread(&ch1, 1, 1, S) == 1 && ch1 != '\n') {
        if (j < 200)
            D->titre[j++] = ch1;
    }
    D->resume = (char *) malloc(50000 * sizeof(char));
    memset(D->resume, 0, 50000);
    j= 0;
    while(fread(&ch1, 1, 1, S) == 1 && ch1 != '\n') {
        if (j < 50000)
            D->resume[j++] = ch1;
    }
    return 0;
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
int
reorder_DB(char *w)
{
    int             i,
                    j,
                    nb;
    char            ch1,
                   *k,
                  **nam,
                   *nam0;
    math_rec       *D,
                    D0;
    FILE           *S;

/*--------------------------------------
    Lecture de DB.STR
--------------------------------------*/
    k = (char *) malloc((size_t) 1000 * sizeof(char));
    memset(k, 0, 1000);
    sprintf(k, "%s/DB.STR", w);
    S = fopen(k, "r");
    if (S == NULL) {
        free(k);
        return 6;
    }
    nb = 0;
    fscanf(S, "%d", &nb);
    if (nb == 0) {
        free(k);
        fclose(S);
        return 0;
    }
    D = (math_rec *) malloc((size_t) nb * sizeof(math_rec));
    nam = (char **) malloc((size_t) nb * sizeof(char *));
    for (i = 0; i < nb; i++)
        nam[i] = NULL;
    fread(&ch1, 1, 1, S);

    for (i = 0; i < nb; i++) {
        lec_DB_STR(S, &D[i]);
        extr_nam(D[i]. name_aut[0], &nam[i]);
    }

    fclose(S);
/*------------------------------------*/


/*--------------------------------------
    Remise en ordre des noms d'auteur
--------------------------------------*/
    for (i = 0; i < nb - 1; i++) {
        for (j = i + 1; j < nb; j++)
            if (est_avant(nam[j], nam[i]) == 1) {
                nam0 = nam[i];
                nam[i] = nam[j];
                nam[j] = nam0;
                D0 = D[i];
                D[i] = D[j];
                D[j] = D0;
            }
    }
/*------------------------------------*/


/*--------------------------------------
    Rcriture de DB.STR
--------------------------------------*/
    S = fopen(k, "w");
    fprintf(S, "%d\n", nb);
    for (i = 0; i < nb; i++)
        add_DB_STR(S, &D[i]);
    fclose(S);
/*------------------------------------*/


    free(k);
    free(D);
    for (i = 0; i < nb; i++)
        if (nam[i] != NULL)
            free(nam[i]);
    free(nam);
    return 0;
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
void
extr_nam(char *k0, char **u)
{
    char           *k,
                  **z,
                   *zz,
                   *zz2;
    int             i,
                    ind,
                    j,
                    len,
                    o;

    k = (char *) malloc((size_t) 1000 * sizeof(char));
    memset(k, 0, 1000);
    len = strlen(k0);
    z = (char **) malloc((size_t) len * sizeof(char *));
    j = 0;
    i = 0;
    o = 0;
    while (i < len && k0[i] == ' ') {
        i++;
    }
    z[0] = (char *) malloc((size_t) len * sizeof(char));
    memset(z[0], 0, len);
    ind = 1;

    while (i < len) {
        if (k0[i] == ' ') {
            i++;
            ind = 0;
        }
        else {
            if (ind == 0) {
                j++;
                z[j] = (char *) malloc((size_t) len * sizeof(char));
                memset(z[j], 0, len);
                ind = 1;
                o = 0;
            }
            z[j][o++] = k0[i];
            i++;
        }
    }

    if (j == 0) {
        if (z[0][0] >= 95)
            z[0][0] -= 32;
        *u = ch_copy(z[0]);
    }
    else {
        zz = z[j - 1];
        if (zz[0] >= 95)
            zz[0] -= 32;
        if (comp(zz, "De") == 1 || comp(zz, "Le") == 1 || comp(zz, "Van") == 1
            || comp(zz, "Von") == 1) {
                o = strlen(z[j]) + strlen(z[j - 1]) + 5;
                *u = (char *) malloc((size_t) o * sizeof(char));
                memset(*u, 0, o);
                sprintf(*u, "%s %s", z[j - 1], z[j]);
        }
        else {
            ind = 0;
            if (j > 1) {
                zz = z[j - 2];
                if (zz[0] >= 95)
                    zz[0] -= 32;
                zz2 = z[j - 1];
                if (comp(zz2, "y") == 1 || comp(zz, "Van") == 1) {
                    o = strlen(z[j]) + strlen(z[j - 1]) + strlen(z[j - 2])+ 5;
                    *u = (char *) malloc((size_t) o * sizeof(char));
                    memset(*u, 0, o);
                    sprintf(*u, "%s %s %s", z[j - 2], z[j - 1], z[j]);
                    ind = 1;
                }
            }
            if (ind == 0) {
                if (z[j][0] >= 95)
                    z[j][0] -= 32;
                *u = ch_copy(z[j]);
            }
        }
    }
    free(k);
    for (i = 0; i <= j; i++)
        free(z[i]);
    free(z);
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------
    nettoyage d'une chaine de caracteres
--------------------------------------------------------------------*/
void
clean_fic(char *w)
{
    int             i,
                    ind,
                    j,
                    len;

    len = strlen(w);
    i = 0;
    ind = 0;

    while (i < len - 7) {
        if (w[i] == '&' && w[i + 2] == 'a' && w[i + 3] == 'c' &&
            w[i + 4] == 'u' && w[i + 5] == 't' && w[i + 6] == 'e' &&
            w[i + 7] == ';') {
            w[i] = w[i + 1];
            for (j = i + 1; j < len - 7; j++)
                w[j] = w[j + 7];
            for (j = len - 7; j < len; j++)
                w[j] = 0;
            len -= 7;
        }
        i++;
    }

    i = 0;

    while (i < len - 1 && ind < 6) {
        if (w[i] == '.' && w[i + 1] != ' ') {
            for (j = len; j > i + 1; j--)
                w[j] = w[j - 1];
            w[i + 1] = ' ';
            len++;
            w[len] = 0;
            ind++;
        }
        i++;
    }

    i = 0;

    while (i < len) {
        if ((w[i] >= 'a' && w[i] <= 'z') || w[i] == '.' || w[i] == '\''
            || w[i] == ' ' || (w[i] >= 'A' &&  w[i] <= 'Z') || w[i] == '-') {
            i++;
        }
        else {
            for (j = i; j < len; j++)
                w[j] = w[j + 1];
            w[len] = 0;
            len--;
        }

    }
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------
--------------------------------------------------------------------*/
void
echange_nom_b(char **p, char **m)
{
    char           *h;

    h = m[0];
    m[0] = p[0];
    p[0] = h;
}
/*------------------------------------------------------------------*/




/*--------------------------------------------------------------------
    donne les faramtres d'un fichier
    *lin : nombre de lignes
    *line_s : longueur maximale d'une ligne
--------------------------------------------------------------------*/
void
file_param(FILE *S, int *lin, int *line_s, int *len)
{
    char            ch1;
    int             i,
                    j,
                    jmax,
                    k;

    i = 0;
    j = 0;
    jmax = 0;
    k = 0;

    while (fread(&ch1, 1, 1, S) == 1) {
        k++;
        if (ch1 == '\n') {
            i++;
            if (jmax < j)
                jmax = j;
            j = 0;
        }
        else
            j++;
    }

    lin[0] = i;
    line_s[0] = jmax;
    len[0] = k;
    rewind(S);
}
/*------------------------------------------------------------------*/





/*--------------------------------------------------------------------
    lecture d'un fichier
    fic[] : les lignes du fichier
    *lin : nombre de lignes
    *line_s : longueur maximale d'une ligne (+2)
--------------------------------------------------------------------*/
void
lit_file(FILE *S, char ***k, int *lin, int *line_s, int i_clean)
{
    int             i0,
                    i,
                    len;
    size_t          N;

    file_param(S, lin, line_s, &len);
    i0 = *line_s + 2;
    N = (size_t) i0;
    k[0] = (char **) malloc((size_t) *lin * sizeof(char **));

    for (i = 0; i < *lin; i++) {
        k[0][i] = (char *) malloc(N * sizeof(char));
        memset(k[0][i], 0, *line_s + 2);
        getline(&k[0][i], &N, S);
        if (i_clean == 1)
            k[0][i][strlen(k[0][i]) - 1] = 0;
    }

    rewind(S);
}
/*------------------------------------------------------------------*/





/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
void
Dzero(math_rec *D, int nb) {
    int             i;

    for (i = 0; i < nb; i++) {
        D[i].fic = NULL;
        D[i].name_aut = NULL;
        D[i].name_aut2 = NULL;
        D[i].titre = NULL;
        D[i].resume = NULL;
        D[i].ref = NULL;
        D[i].fill = 0;
        D[i].nb_aut = 0;
    }
}
/*------------------------------------------------------------------*/





/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
void
Dfree(math_rec *D, int nb) {
    int             i,
                    j;

    for (i = 0; i < nb; i++) {
        if (D[i].fic != NULL)
            free(D[i].fic);
        if (D[i].name_aut != NULL) {
            for (j = 0; j < D[i].nb_aut; j++) {
                if ((D[i].name_aut)[j] != NULL)
                    free((D[i].name_aut)[j]);
            }

            free(D[i].name_aut);
        }
        if (D[i].name_aut2 != NULL) {
            for (j = 0; j < D[i].nb_aut; j++) {
                if ((D[i].name_aut2)[j] != NULL)
                    free((D[i].name_aut2)[j]);
            }

            free(D[i].name_aut2);
        }
        if (D[i].titre != NULL)
            free(D[i].titre);
        if (D[i].resume != NULL)
            free(D[i].resume);
        if (D[i].ref != NULL)
            free(D[i].ref);
    }

    free(D);
}
/*------------------------------------------------------------------*/





/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
void
nettoie_x(char *k)
{
    int             i,
                    j,
                    ind,
                    len;

    len = strlen(k);
    i = 0;
    ind = 0;

    while (k[i] == 32) {
        ind = 1;
        if (i == len - 1) {
            ind = 0;
            break;
        }
        i++;
    }

    if (ind == 1) {
        for (j = 0; j < len - i; j++)
            k[j] = k[j + i];
        for (j = len - i; j < len; j++)
            k[j] = 0;
        len -= i;
    }

    i = len - 1;
    ind = 0;

    while (k[i] == 32) {
        ind = 1;
        if (i == 0) {
            ind = 0;
            break;
        }
        i--;
    }

    if (ind == 1)
        for (j = i + 1; j < len; j++)
            k[j] = 0;
}
/*------------------------------------------------------------------*/





/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
void
nettoie_x2(char *k)
{
    int             i,
                    j,
                    len;

    len = strlen(k);
    i = 0;

    while (i < len) {
        if (k[i] == 32)  {
            for (j = i; j < len - 1; j++)
                k[j] = k[j + 1];
            k[len - 1] = 0;
            len--;
        }
        i++;
    }
}
/*------------------------------------------------------------------*/





/*--------------------------------------------------------------------

--------------------------------------------------------------------*/
void
clean_resume(char *m, char **m2)
{
	int             l,
	                j,
	                k,
	                ind;

    l = strlen(m);
    j = 0;

    for (k = 1; k < l; k++) {
		if (m[k] == '<')
		    break;
        if (m[k] == '>') {
			j = k + 1;
			break;
		}
	}
	 
    k = -1;
    ind = 0;
    
    while (j < l) {
		if (ind == 0) {
			if (m[j] != '<' && m[j] != '\n') {
			    k++;
			    m2[0][k] = m[j];
			}
			else {
				if (m[j] == '<')
			        ind = 1;
			}
	    }
	    else {
			if (m[j] == '>')
			    ind = 0;
	    }
	    j++;
	}

    m2[0][k+1] = 0;
    if (m2[0][0] == '>')
        m2[0][0] = ' ';
	if (k >= 9) {
		if (m2[0][0] == 'A' && m2[0][1] == 'b' && m2[0][2] == 's' && 
		    m2[0][3] == 't' && m2[0][4] == 'r' && m2[0][5] == 'a' &&
		    m2[0][6] == 'c' && m2[0][7] == 't' && m2[0][8] == ':') {
		    for (j = 0; j <= k - 8; j++)
		        m2[0][j] = m2[0][j + 9];
		}
    }
}
/*------------------------------------------------------------------*/





































